%Discrete Pareto Estimator

%Estimates the exponent for the discrete Pareto when provided with the
%a vector of observations (data). This is for the special case where the
%minimum attainable value, a, is equal to 1 as would be the case for most
%ecological data.

function [exponent] =discretepareto_mle(data)

%Determine a starting point for the numerical search by fitting the
%distribution using MLE for the simple Pareto
lambda0=mle_pareto(data,min(data));

%Find the exponent numerically by finding the value of the exponent that
%sets the relevent equation in Table 1 to be equal to 0. This equation is
%given by the nested function 'discretepareto_mle_equation'.
exponent = fzero(@(lambda) discretepareto_mle_equation(lambda,mean(log(data))),lambda0);
    
    %Nested function that provides the equation for the root finder to set
    %to zero - mle equation for rho of the discrete pareto. rho = lambda-1.
    %following JKK
    function y = discretepareto_mle_equation(lambda,meanlogx)
    y=meanlogx+zeta(1,-lambda)/zeta(-lambda);
    end

end